- :meth:`metrics.PrecisionRecallDisplay.from_estimator` and 
  :meth:`metrics.PrecisionRecallDisplay.from_predictions` now 
  correctly plot chance level line when `y_true` is a pytorch tensor.
  By :user:`Lucas Oliveira <lucolivi>`.